"""
Compute average reward per action (i.e., persuasive strategy).

Author: Shirley Li (based on code by Nele Albers, https://doi.org/10.4121/22153898.v1)
]Date: June 2024
"""

import numpy as np
import reward_utils as util


def compute_avg_reward(data, weights, cost, num_act):
    """Compute the average reward per action.
    Args:
        data (list): List with samples of the form <s0, s1, a, r>.
        weights (list): Weights for each reward.
        cost (float): The cost factor.
        num_act (int): Number of possible actions.
    Returns:
        np-array: Average reward per action.
    """
    num_samples = len(data)

    # All separate rewards
    list_of_rewards = list(np.array(data, dtype=object)[:, 3])
    list_of_actions = list(np.array(data, dtype=object)[:, 2])
    
    # Map effort responses to rewards from -1 to 1, with the mean mapped to 0.
    reward_list = util.get_weighted_rewards_list(list_of_rewards, weights, list_of_actions, cost)
    # now write these obtained reward values into "data" in place of the original rewards
    for i in range(len(reward_list)):
        data[i][3] = reward_list[i]
  
    rewards = np.zeros(num_act)
    trials = np.zeros(num_act)

    for data_index in range(num_samples):
        rewards[data[data_index][2]] += reward_list[data_index]
        trials[data[data_index][2]] += 1

    # Calculate average reward per action
    avg_reward = np.divide(rewards, trials,
                           out = np.zeros_like(rewards),
                           where=trials!=0)

    return avg_reward
 